/*
adapted from OpenLinkMap Copyright (C) 2010 Alexander Matheisen
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it under certain conditions.
See olm.openstreetmap.de/info for details.
*/

function createMap()
{
	// position to zoom on if no permalink is given and geolocation isn't supported
	var startLat = 49.5129;
	var startLon = 11.2791;
	var startZoom = 14;
	// projection
	var wgs84 = new OpenLayers.Projection("EPSG:4326");
	OpenLayers.Lang.setCode('de');
	map = new OpenLayers.Map('map',
	{
		controls: [],
		projection: new OpenLayers.Projection("EPSG:900913"),
		displayProjection: wgs84,
		maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34, 20037508.34, 20037508.34),
		numZoomLevels: 19,
		maxResolution: 156543,
		units: 'meters'
	});
	map.addControl(new OpenLayers.Control.PanZoomBar());
	map.addControl(new OpenLayers.Control.ScaleLine());
	map.addControl(new OpenLayers.Control.MousePosition());
	map.addControl(new OpenLayers.Control.LayerSwitcher());
	map.addControl(new OpenLayers.Control.Permalink());
	map.addControl(new OpenLayers.Control.Navigation());
	var mapnikMap = new OpenLayers.Layer.OSM.Mapnik("Mapnik",
	{
		transitionEffect: 'resize'
	});
	var osmarenderMap = new OpenLayers.Layer.OSM.Osmarender("Osmarender",
	{
		transitionEffect: 'resize'
	});
	map.addLayers([mapnikMap, osmarenderMap, linkLayer, wikipediaLayer]);
	// if no permalink is given
	if (document.location == 'http://www.lauf.de/index.php?mid=244')
	{
		// jump to given start position
		var startPosition = new OpenLayers.LonLat(startLon, startLat).transform(wgs84, map.getProjectionObject());
		map.setCenter(startPosition, startZoom);
	}
	// if a permalink is given
	else
	{
		// to show the marker directly, otherwise they only would be visible after moving the map
		map.setCenter(map.getCenter(), map.getZoom());
	}
	// allow pressing enter instead of clicking the searchbutton
	initEnter();
	// set focus to searchbox
	document.getElementById('searchBox').focus();
}

function initEnter()
{
	if (navigator.appName == "Microsoft Internet Explorer")
	{
		if (window.event.keyCode == "13")
		{
			requestSearch();
		}
	}
	else
	{
		document.captureEvents(Event.KEYPRESS);
		document.onkeypress = keyPressed;
	}
}

function keyPressed(key)
{
	if (key.which == "13")
	{
		requestSearch();
	}
}

function translateType(placeType)
{
	var translatedType = searchTypesDE[placeType];
	if(typeof translatedType=='undefined')
		return "";
	else
		translatedType += "&nbsp;";
	return translatedType;
}

function requestSearch()
{
	var placesList;
	document.getElementById('resultList').innerHTML = "<b>Laden...</b>";
	var searchString = document.getElementById('searchBox').value;
	if (searchString.length == 0)
		document.getElementById('resultList').innerHTML = "<b>Leere Eingabe.<br />Nichts gefunden.</b>";
	else
	{
		// only search in lauf
		searchString += ", lauf";
		// replace spaces with +
		searchString = searchString.replace(/ /g, "+");
		var searchUrl = "http://nominatim.openstreetmap.org/search?format=xml&polygon=0&addressdetails=0&q="+searchString;
		var searchRequest = OpenLayers.Request.GET(
		{
			url: searchUrl,
			async: false
		});
		document.getElementById('resultList').innerHTML = searchRequest.responseText;
		placesList = searchRequest.responseXML.getElementsByTagName('place');
		if (placesList.length > 0)
		{
			document.getElementById('resultList').innerHTML = "<br />";
			for (var i = 0; i < placesList.length; i++)
			{
				var place = placesList[i];
				var placeBoundingbox = place.getAttribute('boundingbox');
				var placeKey = place.getAttribute('class');
				var placeValue = place.getAttribute('type');
				var placeName = place.getAttribute('display_name');
				var placeId = place.getAttribute('osm_id');
				var placeLat = place.getAttribute('lat');
				var placeLon = place.getAttribute('lon');
				var placeType = placeKey+"="+placeValue;
				// translation of object types into german
				placeType = translateType(placeType);
				var placeBounds = placeBoundingbox.split(",");
				// remove info that isn't needed
				placeName = placeName.replace(", Nürnberger Land, 91207, Regierungsbezirk Mittelfranken, Freistaat Bayern, Bundesrepublik Deutschland", "");
				var placeItem = "<b>"+placeType+"</b><a href=\"javascript:showPlace("+placeBounds[2]+","+placeBounds[0]+","+placeBounds[3]+","+placeBounds[1]+","+placeId+","+placeLat+","+placeLon+");\">"+placeName+"</a><br /><br />";
				document.getElementById('resultList').innerHTML += placeItem;
			}
		}
		else
			document.getElementById('resultList').innerHTML = "<b>Nichts gefunden.</b>";
	}
}

function showPlace(left, bottom, right, top, id, lat, lon)
{
	var wgs84 = new OpenLayers.Projection("EPSG:4326");
	var bounds = new OpenLayers.Bounds(left, bottom, right, top).transform(wgs84, map.getProjectionObject());
	map.zoomToExtent(bounds, true);
}